==> mastercard_spendcontrols-1.0.1.tar.gz: mastercard_spendcontrols-1.0.1/mastercardspendcontrols/crossborder.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Crossborder(BaseObject):
	"""
	
	"""

	__config = {
		
		"55694722-0ef1-4b22-88d6-f521e58c52ef" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "delete", [], []),
		
		"d446dd52-5080-4422-9cfe-eaefefb3f15a" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "query", [], []),
		
		"2115de1b-b65f-48cf-a562-72b6d4628362" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Crossborder by id

		@param str id
		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("55694722-0ef1-4b22-88d6-f521e58c52ef", Crossborder(mapObj))

	def delete(self):
		"""
		Delete object of type Crossborder

		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("55694722-0ef1-4b22-88d6-f521e58c52ef", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Crossborder by id and optional criteria
		@param type criteria
		@return Crossborder object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("d446dd52-5080-4422-9cfe-eaefefb3f15a", Crossborder(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Crossborder

		@param Dict mapObj, containing the required parameters to create a new object
		@return Crossborder of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("2115de1b-b65f-48cf-a562-72b6d4628362", Crossborder(mapObj))

==> mastercard_spendcontrols-1.0.2.tar.gz: mastercard_spendcontrols-1.0.2/mastercardspendcontrols/crossborder.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Crossborder(BaseObject):
	"""
	
	"""

	__config = {
		
		"ecc02cec-7c50-49d2-a5ca-b53f6cc5f78f" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "delete", [], []),
		
		"d7f772c6-dd05-4717-85ca-f5de0e7a33b9" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "query", [], []),
		
		"c0f3632d-192b-42f0-bcfc-dcd43c0725b0" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Crossborder by id

		@param str id
		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("ecc02cec-7c50-49d2-a5ca-b53f6cc5f78f", Crossborder(mapObj))

	def delete(self):
		"""
		Delete object of type Crossborder

		@return Crossborder of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("ecc02cec-7c50-49d2-a5ca-b53f6cc5f78f", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Crossborder by id and optional criteria
		@param type criteria
		@return Crossborder object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("d7f772c6-dd05-4717-85ca-f5de0e7a33b9", Crossborder(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Crossborder

		@param Dict mapObj, containing the required parameters to create a new object
		@return Crossborder of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("c0f3632d-192b-42f0-bcfc-dcd43c0725b0", Crossborder(mapObj))
